Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4326)

Unified Diff: chrome/browser/sync/test/integration/performance/sync_timing_helper.h

Issue 2379433002: [Sync] Refactoring of sync integration test checkers to remove boilerplate await methods. (Closed)
Patch Set: Rebase Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/performance/sync_timing_helper.h
diff --git a/chrome/browser/sync/test/integration/performance/sync_timing_helper.h b/chrome/browser/sync/test/integration/performance/sync_timing_helper.h
index 10cadccfec090857f12116b6301a81b04a3e100f..b2af9577b1739d458a45d5c0a2a7f8ff81a3e3d8 100644
--- a/chrome/browser/sync/test/integration/performance/sync_timing_helper.h
+++ b/chrome/browser/sync/test/integration/performance/sync_timing_helper.h
@@ -8,41 +8,34 @@
#include <string>
#include <vector>
-#include "base/macros.h"
-
namespace base {
class TimeDelta;
}
class ProfileSyncServiceHarness;
-class SyncTimingHelper {
- public:
- SyncTimingHelper();
- ~SyncTimingHelper();
-
- // Returns the time taken for |client| to complete a single sync cycle.
- static base::TimeDelta TimeSyncCycle(ProfileSyncServiceHarness* client);
-
- // Returns the time taken for both |client| and |partner| to complete a sync
- // cycle.
- static base::TimeDelta TimeMutualSyncCycle(
- ProfileSyncServiceHarness* client, ProfileSyncServiceHarness* partner);
-
- // Returns the time taken for all clients in |clients| to complete their
- // respective sync cycles.
- static base::TimeDelta TimeUntilQuiescence(
- std::vector<ProfileSyncServiceHarness*>& clients);
-
- // Print a timing measurement in a format appropriate for the chromium perf
- // dashboard. Simplified version of methods defined in
- // chrome/test/ui/ui_perf_test.{h,cc}.
- static void PrintResult(const std::string& measurement,
- const std::string& trace,
- const base::TimeDelta& dt);
-
- private:
- DISALLOW_COPY_AND_ASSIGN(SyncTimingHelper);
-};
+namespace sync_timing_helper {
+
+// Returns the time taken for |client| to complete a single sync cycle.
+base::TimeDelta TimeSyncCycle(ProfileSyncServiceHarness* client);
+
+// Returns the time taken for both |client| and |partner| to complete a sync
+// cycle.
+base::TimeDelta TimeMutualSyncCycle(ProfileSyncServiceHarness* client,
+ ProfileSyncServiceHarness* partner);
+
+// Returns the time taken for all clients in |clients| to complete their
+// respective sync cycles.
+base::TimeDelta TimeUntilQuiescence(
+ const std::vector<ProfileSyncServiceHarness*>& clients);
+
+// Print a timing measurement in a format appropriate for the chromium perf
+// dashboard. Simplified version of methods defined in
+// chrome/test/ui/ui_perf_test.{h,cc}.
+void PrintResult(const std::string& measurement,
+ const std::string& trace,
+ const base::TimeDelta& dt);
+
+} // namespace sync_timing_helper
#endif // CHROME_BROWSER_SYNC_TEST_INTEGRATION_PERFORMANCE_SYNC_TIMING_HELPER_H_

Powered by Google App Engine
This is Rietveld 408576698